.. TOM Toolkit documentation master file, created by
   sphinx-quickstart on Mon Aug 26 08:31:03 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

API Documentation
=================

.. toctree::
  :maxdepth: 1
  :includehidden:

  tom_alerts/index
  tom_catalogs/index
  tom_common/index
  tom_dataproducts/index
  tom_observations/index
  tom_targets/index
  management_commands